import { login, logout, getInfo,refreshToken } from "@/api/login";
import { getToken, setToken, removeToken, setExpiresIn, getClientToken, setClientToken, removeClientToken, getUSerToken, setUserToken, removeUSerToken } from '@/utils/auth'
import { isHttp, isEmpty } from "@/utils/validate";
import defAva from "@/assets/images/profile.jpg";
import { singleSigngetInfo, enterpriseLogout, governmentGetInfo } from "@/api/login/index";

const user = {
  state: {
    token: getToken(),
    clientToken: getClientToken(),
    userToken: getUSerToken(),
    id: '',
    name: '',
    avatar: '',
    roles: [],
    permissions: [],
    expires_in: '',
    enterpriseId: '',
    nickName: '',
    userType: '',
    deptId: '',
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token;
    },
    SET_ID: (state, id) => {
      state.id = id;
    },
    SET_NAME: (state, name) => {
      state.name = name;
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar;
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles;
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions;
    },
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim();
      const password = userInfo.password;
      const code = userInfo.code;
      const uuid = userInfo.uuid;
      const loginRole = userInfo.loginRole;
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid, loginRole)
          .then((res) => {
            setToken(res.token);
            commit("SET_TOKEN", res.token);
            resolve();
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
    // 企业端登录
    SingleSignOnGetInfo({ commit, state },info) {
      return new Promise((resolve, reject) => {
        singleSigngetInfo({clientToken: info.clientToken}).then(res => {
          // if (res.data.usertype && res.data.usertype.length > 0) { // 验证返回的roles是否是一个非空数组
          //   let roles = [];
          //   roles.push(res.data.usertype)
          //   commit('SET_ROLES', roles)
          // } else {
          //   commit('SET_ROLES', ['ROLE_DEFAULT'])
          // }
          setClientToken(info.clientToken)
          commit('SET_CLIENTTOKEN', res.data.token)
          setToken(res.data.token)
          commit('SET_TOKEN', res.data.token)
          // commit('SET_USERTYPE', res.data.usertype)
          // console.log(res.data.usertype,"res.data.usertype");
          // console.log(state.roles,"state.roles");
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 政务端登录
    governmentLogin({ commit, state }, info) {
      return new Promise((resolve, reject) => {
        governmentGetInfo(info)
          .then((res) => {
            // console.log(res);
            setUserToken(info.userToken);
            commit("SET_USERTOKEN", res.data.token);
            setToken(res.data.token);
            commit("SET_TOKEN", res.data.token);
            resolve();
          })
          .catch((error) => {
            // console.log(error);
            // reject(error)
          });
      });
    },
    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo()
          .then((res) => {
            const user = res.user;
            let avatar = user.avatar || "";
            if (!isHttp(avatar)) {
              avatar = isEmpty(avatar)
                ? defAva
                : process.env.VUE_APP_BASE_API + avatar;
            }
            if (res.roles && res.roles.length > 0) {
              // 验证返回的roles是否是一个非空数组
              commit("SET_ROLES", res.roles);
              commit("SET_PERMISSIONS", res.permissions);
            } else {
              commit("SET_ROLES", ["ROLE_DEFAULT"]);
            }
            commit("SET_ID", user.userId);

            commit("SET_NAME", user.nickName);

            commit("SET_AVATAR", avatar);
            resolve(res);
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
        // 刷新token
    RefreshToken({commit, state}) {
      return new Promise((resolve, reject) => {
        refreshToken(state.token).then(res => {
          setExpiresIn(res.data)
          commit('SET_EXPIRES_IN', res.data)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 退出系统
LogOut({ commit, state }) {
  if (!state.token && state.clientToken) {
    return enterpriseLogout({ clienttoken: state.clientToken })
      .then(() => {
        commit('SET_CLIENTTOKEN', '');
        removeClientToken();
      });
  } else if (state.token && state.clientToken) {
    return enterpriseLogout({ clienttoken: state.clientToken })
      .then(() => {
        commit('SET_CLIENTTOKEN', '');
        removeClientToken();
        return logout(state.token); // 再调用本地登出
      })
      .then(() => {
        commit('SET_TOKEN', '');
        commit('SET_ROLES', []);
        commit('SET_PERMISSIONS', []);
        removeToken();
        return Promise.resolve({ userType: state.userType });
      });
  } else {
    return new Promise((resolve, reject) => {
      logout(state.token).then(() => {
        commit('SET_TOKEN', '');
        commit('SET_ROLES', []);
        commit('SET_PERMISSIONS', []);
        removeToken();
        resolve({ userType: state.userType });
      }).catch(error => {
        reject(error);
      });
    });
  }
},

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise((resolve) => {
        commit("SET_TOKEN", "");
        removeToken();
        resolve();
      });
    },
  },
};

export default user;
